@@ -29,7 +29,7 @@ Net::Etcd - etcd v3 REST API.
 
 =cut
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 =head1 SYNOPSIS
 
@@ -54,6 +54,9 @@ our $VERSION = '0.013';
     # return array { key => value } pairs from range request.
     my @users = $range->all
 
+    # delete single key
+    $etcd->deleterange({ key => 'test0' });
+
     # watch key range, streaming.
     $watch = $etcd->watch( { key => 'foo', range_end => 'fop'}, sub {
         my ($result) =  @_;
@@ -70,7 +73,7 @@ our $VERSION = '0.013';
     $etcd->user( { name => 'samba', password => 'foo' } )->add;
 
     # add new user role
-	$role = $etcd->role( { name => 'myrole' } )->add;
+    $role = $etcd->role( { name => 'myrole' } )->add;
 
     # grant read permission for the foo key to myrole
     $etcd->role_perm( { name => 'myrole', key => 'foo', permType => 'READWRITE' } )->grant;
@@ -227,13 +230,13 @@ Grants or revoke permission of a specified key or range to a specified role.
 =cut
 
 sub role_perm {
-    my ( $self, $options ) = @_; 
+    my ( $self, $options ) = @_;
     my $cb = pop if ref $_[-1] eq 'CODE';
     my $perm = Net::Etcd::Auth::RolePermission->new(
         etcd     => $self,
         cb       => $cb,
         ( $options ? %$options : () ),
-    );  
+    );
 }
 
 =head2 user_role
@@ -259,8 +262,8 @@ sub user_role {
 See L<Net::Etcd::Auth>
 
     $etcd->auth({ name => 'samba', password => 'foo' })->authenticate;
-	$etcd->auth()->enable;
-	$etcd->auth()->disable
+    $etcd->auth()->enable;
+    $etcd->auth()->disable
 
 =cut
 
@@ -336,6 +339,14 @@ See L<Net::Etcd::KV::Put>
 
 =cut
 
+=head2 deleterange
+
+See L<Net::Etcd::KV::DeleteRange>
+
+    $etcd->deleterange({ key=>'test0' });
+
+=cut
+
 =head2 range
 
 See L<Net::Etcd::KV::Range>
@@ -357,7 +368,7 @@ See L<Net::Etcd::KV::Txn>
 See L<Net::Etcd::KV::Op>
 
     $etcd->op({ request_put => $put });
-	$etcd->op({ request_delete_range => $range });
+    $etcd->op({ request_delete_range => $range });
 
 =cut
 
@@ -387,13 +398,17 @@ sub BUILD {
         $msg .= ">> Please install etcd - https://coreos.com/etcd/docs/latest/";
         die $msg;
     }
-	# set the intial auth token
+    # set the intial auth token
     $self->auth()->authenticate;
 }
 
 =head1 AUTHOR
 
-Sam Batschelet, <sbatschelet at mac.com>
+Sam Batschelet (hexfusion)
+
+=head1 CONTRIBUTORS
+
+Ananth Kavuri
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -405,6 +420,8 @@ The L<etcd|https://github.com/coreos/etcd> v3 API is in heavy development and ca
  L<api_reference_v3|https://github.com/coreos/etcd/blob/master/Documentation/dev-guide/api_reference_v3.md>
 for latest details.
 
+Authentication provided by this module will only work with etcd v3.3.0+
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2017 Sam Batschelet (hexfusion).
