@@ -20,7 +20,7 @@ Net::Etcd::Range
 
 =cut
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 =head1 DESCRIPTION
 
@@ -217,20 +217,4 @@ has max_create_revision => (
     isa => Int,
 );
 
-=head2 delete
-
-DeleteRange deletes the given range from the key-value store. A delete request increments the
-revision of the key-value store and generates a delete event in the event history for every
-deleted key.
-
-    $etcd->range({key =>'test0'})->delete
-
-=cut
-
-sub delete {
-    my ( $self ) = @_;
-    $self->{endpoint} => '/kv/deleterange',
-    return $self->request;
-}
-
 1;
